aboutsummaryrefslogtreecommitdiff
path: root/drivers/staging/comedi/drivers/adq12b.c
diff options
context:
space:
mode:
authorBill Pemberton <wfp5p@virginia.edu>2009-03-16 22:05:25 -0400
committerGreg Kroah-Hartman <gregkh@suse.de>2009-04-03 14:53:56 -0700
commit139dfbdfacb02e3ef3df936d2fabd1ad5f14ea88 (patch)
treef31facb21b85d6a9ebc4f7d9daa840a8149f8a3f /drivers/staging/comedi/drivers/adq12b.c
parentd163679ceec20c50f9aee880fa76c0c1185244a8 (diff)
Staging: comedi: Remove comedi_driver typedef
Signed-off-by: Bill Pemberton <wfp5p@virginia.edu> Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
Diffstat (limited to 'drivers/staging/comedi/drivers/adq12b.c')
-rw-r--r--drivers/staging/comedi/drivers/adq12b.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/drivers/staging/comedi/drivers/adq12b.c b/drivers/staging/comedi/drivers/adq12b.c
index 99a7a056208..b5a32811680 100644
--- a/drivers/staging/comedi/drivers/adq12b.c
+++ b/drivers/staging/comedi/drivers/adq12b.c
@@ -157,14 +157,14 @@ typedef struct{
#define devpriv ((adq12b_private *)dev->private)
/*
* The comedi_driver structure tells the Comedi core module
* which functions to call to configure/deconfigure (attach/detach)
* the board, and also about the kernel module that contains
* the device code.
*/
static int adq12b_attach(struct comedi_device *dev,comedi_devconfig *it);
static int adq12b_detach(struct comedi_device *dev);
-static comedi_driver driver_adq12b={
+static struct comedi_driver driver_adq12b={
driver_name: "adq12b",
module: THIS_MODULE,
attach: adq12b_attach,
@@ -157,14 +157,14 @@ typedef struct{
#define devpriv ((adq12b_private *)dev->private)
/*
- * The comedi_driver structure tells the Comedi core module
+ * The struct comedi_driver structure tells the Comedi core module
* which functions to call to configure/deconfigure (attach/detach)
* the board, and also about the kernel module that contains